@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: get_template.py 9906 2017-04-23 15:13:49Z Lavender $
+# $Id: get_template.py 9978 2017-05-20 15:24:37Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,15 +12,17 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-23 23:13:49 +0800 (週日, 23 四月 2017) $
-# $Revision: 9906 $
+# $Date: 2017-05-20 23:24:37 +0800 (週六, 20 五月 2017) $
+# $Revision: 9978 $
 
 import os
 import logging
 import shutil
 
 from django.core.management.base import BaseCommand, CommandError
-from django.conf import settings
+
+from Zephyrus.boilerplate.management.commands import (
+    TEMPLATES_DIR_PATH, STATIC_DIR_PATH, IMAGES_DIR_PATH, ROOT_DIR_PATH)
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -29,31 +31,6 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
-if hasattr(settings, 'TEMPLATES'):
-    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
-else:
-    TEMPLATES_DIR_PATH = os.path.abspath(
-        os.path.join('.', 'templates'))
-
-if settings.DEBUG:
-    if hasattr(settings, 'STATICFILES_DIRS'):
-        STATIC_DIT_PATH = settings.STATICFILES_DIRS[0]
-    else:
-        STATIC_DIT_PATH = os.path.abspath(
-            os.path.join('.', 'static'))
-else:
-    if hasattr(settings, 'STATIC_ROOT'):
-        STATIC_DIT_PATH = settings.STATIC_ROOT
-    else:
-        STATIC_DIT_PATH = os.path.abspath(
-            os.path.join('.', 'static'))
-    
-IMAGES_DIT_PATH = os.path.abspath(
-    os.path.join('.', 'images'))
-
-ROOT_DIR_PATH = os.path.abspath(
-    os.path.join('.'))
-
 class Command(BaseCommand):
 
     help = 'Copy html to templates and copy static files to static.'
@@ -78,17 +55,17 @@ class Command(BaseCommand):
             logger.info("Create Temeplates folder.")
 
         try:
-            shutil.rmtree(STATIC_DIT_PATH)
+            shutil.rmtree(STATIC_DIR_PATH)
             logger.info("Remove static folder.")
         except Exception as e:
             logger.error("Static folder is not exist.")
-            os.mkdir(STATIC_DIT_PATH)
+            os.mkdir(STATIC_DIR_PATH)
         else:
-            os.mkdir(STATIC_DIT_PATH)
+            os.mkdir(STATIC_DIR_PATH)
             logger.info("Create static folder.")
             
         try:
-            shutil.rmtree(IMAGES_DIT_PATH)
+            shutil.rmtree(IMAGES_DIR_PATH)
             logger.info("Remove images folder.")
         except Exception as e:
             logger.error("Images folder is not exist.")
@@ -97,7 +74,7 @@ class Command(BaseCommand):
         logger.info("-----Start copy templates-----")
         
         imgPath = os.path.join(path, 'images')
-        shutil.copytree(imgPath, IMAGES_DIT_PATH)
+        shutil.copytree(imgPath, IMAGES_DIR_PATH)
         logger.info("Copy images folder to root.")
 
 
@@ -117,12 +94,12 @@ class Command(BaseCommand):
                         logger.info(
                             'Copy %s to templates folder.' % fileName)
                     else:
-                        dst = os.path.join(STATIC_DIT_PATH, fileName)
+                        dst = os.path.join(STATIC_DIR_PATH, fileName)
                         shutil.copyfile(filePath, dst)
                         logger.info('Copy %s to static folder.' % fileName)
                 for dirName in dirs:
                     dirPath = os.path.join(root, dirName)
-                    dst = os.path.join(STATIC_DIT_PATH, dirName)
+                    dst = os.path.join(STATIC_DIR_PATH, dirName)
                     shutil.copytree(dirPath, dst)
                     logger.info('Copy %s to static folder.' % dirName)
                 break
